=begin
#Zoom API

#The Zoom API allows developers to safely and securely access information from Zoom. You can use this API to build private services or public applications on the [Zoom App Marketplace](http://marketplace.zoom.us). To learn how to get your credentials and create private/public applications, read our [Authorization Guide](https://marketplace.zoom.us/docs/guides/authorization/credentials). All endpoints are available via `https` and are located at `api.zoom.us/v2/`.  For instance you can list all users on an account via `https://api.zoom.us/v2/users/`.

OpenAPI spec version: 2.0.0
Contact: developersupport@zoom.us
Generated by: https://github.com/swagger-api/swagger-codegen.git
Swagger Codegen version: 2.4.12

=end

require 'date'

module ZoomUs
  module Models
    class RoomsroomIdBasic
      # Name of the Zoom Room.
      attr_accessor :name

      # The email address to be used for reporting Zoom Room issues.
      attr_accessor :support_email

      # The phone number to be used for reporting Zoom Room issues.
      attr_accessor :support_phone

      # 1-16 digit number or characters that is used to secure your Zoom Rooms application. This code must be entered on your Zoom Room Controller to change settings or sign out.
      attr_accessor :room_passcode

      # Require code to exit out of Zoom Rooms application to switch between other apps.
      attr_accessor :required_code_to_ext

      # Hide this Zoom Room from your Contact List.
      attr_accessor :hide_room_in_contacts

      # Attribute mapping from ruby-style variable name to JSON key.
      def self.attribute_map
        {
          :'name' => :'name',
          :'support_email' => :'support_email',
          :'support_phone' => :'support_phone',
          :'room_passcode' => :'room_passcode',
          :'required_code_to_ext' => :'required_code_to_ext',
          :'hide_room_in_contacts' => :'hide_room_in_contacts'
        }
      end

      # Attribute type mapping.
      def self.swagger_types
        {
          :'name' => :'String',
          :'support_email' => :'String',
          :'support_phone' => :'String',
          :'room_passcode' => :'String',
          :'required_code_to_ext' => :'BOOLEAN',
          :'hide_room_in_contacts' => :'BOOLEAN'
        }
      end

      # Initializes the object
      # @param [Hash] attributes Model attributes in the form of hash
      def initialize(attributes = {})
        return unless attributes.is_a?(Hash)

        # convert string to symbol for hash key
        attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

        if attributes.has_key?(:'name')
          self.name = attributes[:'name']
        end

        if attributes.has_key?(:'support_email')
          self.support_email = attributes[:'support_email']
        end

        if attributes.has_key?(:'support_phone')
          self.support_phone = attributes[:'support_phone']
        end

        if attributes.has_key?(:'room_passcode')
          self.room_passcode = attributes[:'room_passcode']
        end

        if attributes.has_key?(:'required_code_to_ext')
          self.required_code_to_ext = attributes[:'required_code_to_ext']
        end

        if attributes.has_key?(:'hide_room_in_contacts')
          self.hide_room_in_contacts = attributes[:'hide_room_in_contacts']
        end
      end

      # Show invalid properties with the reasons. Usually used together with valid?
      # @return Array for valid properties with the reasons
      def list_invalid_properties
        invalid_properties = Array.new
        if !@room_passcode.nil? && @room_passcode.to_s.length > 16
          invalid_properties.push('invalid value for "room_passcode", the character length must be smaller than or equal to 16.')
        end

        if !@room_passcode.nil? && @room_passcode.to_s.length < 1
          invalid_properties.push('invalid value for "room_passcode", the character length must be great than or equal to 1.')
        end

        invalid_properties
      end

      # Check to see if the all the properties in the model are valid
      # @return true if the model is valid
      def valid?
        return false if !@room_passcode.nil? && @room_passcode.to_s.length > 16
        return false if !@room_passcode.nil? && @room_passcode.to_s.length < 1
        true
      end

      # Custom attribute writer method with validation
      # @param [Object] room_passcode Value to be assigned
      def room_passcode=(room_passcode)
        if !room_passcode.nil? && room_passcode.to_s.length > 16
          fail ArgumentError, 'invalid value for "room_passcode", the character length must be smaller than or equal to 16.'
        end

        if !room_passcode.nil? && room_passcode.to_s.length < 1
          fail ArgumentError, 'invalid value for "room_passcode", the character length must be great than or equal to 1.'
        end

        @room_passcode = room_passcode
      end

      # Checks equality by comparing each attribute.
      # @param [Object] Object to be compared
      def ==(o)
        return true if self.equal?(o)
        self.class == o.class &&
          name == o.name &&
          support_email == o.support_email &&
          support_phone == o.support_phone &&
          room_passcode == o.room_passcode &&
          required_code_to_ext == o.required_code_to_ext &&
          hide_room_in_contacts == o.hide_room_in_contacts
      end

      # @see the `==` method
      # @param [Object] Object to be compared
      def eql?(o)
        self == o
      end

      # Calculates hash code according to all attributes.
      # @return [Fixnum] Hash code
      def hash
        [name, support_email, support_phone, room_passcode, required_code_to_ext, hide_room_in_contacts].hash
      end

      # Builds the object from hash
      # @param [Hash] attributes Model attributes in the form of hash
      # @return [Object] Returns the model itself
      def build_from_hash(attributes)
        return nil unless attributes.is_a?(Hash)
        self.class.swagger_types.each_pair do |key, type|
          if type =~ /\AArray<(.*)>/i
            # check to ensure the input is an array given that the the attribute
            # is documented as an array but the input is not
            if attributes[self.class.attribute_map[key]].is_a?(Array)
              self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
            end
          elsif !attributes[self.class.attribute_map[key]].nil?
            self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
          end # or else data not found in attributes(hash), not an issue as the data can be optional
        end

        self
      end

      # Deserializes the data based on type
      # @param string type Data type
      # @param string value Value to be deserialized
      # @return [Object] Deserialized data
      def _deserialize(type, value)
        case type.to_sym
        when :DateTime
          ::DateTime.parse(value)
        when :Date
          ::Date.parse(value)
        when :String
          value.to_s
        when :Integer
          value.to_i
        when :Float
          value.to_f
        when :BOOLEAN
          if value.to_s =~ /\A(true|t|yes|y|1)\z/i
            true
          else
            false
          end
        when :Object
          # generic object (usually a Hash), return directly
          value
        when /\AArray<(?<inner_type>.+)>\z/
          inner_type = Regexp.last_match[:inner_type]
          value.map { |v| _deserialize(inner_type, v) }
        when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
          k_type = Regexp.last_match[:k_type]
          v_type = Regexp.last_match[:v_type]
          {}.tap do |hash|
            value.each do |k, v|
              hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
            end
          end
        else # model
          temp_model = Models.const_get(type).new
          temp_model.build_from_hash(value)
        end
      end

      # Returns the string representation of the object
      # @return [String] String presentation of the object
      def to_s
        to_hash.to_s
      end

      # to_body is an alias to to_hash (backward compatibility)
      # @return [Hash] Returns the object in the form of hash
      def to_body
        to_hash
      end

      # Returns the object in the form of hash
      # @return [Hash] Returns the object in the form of hash
      def to_hash
        hash = {}
        self.class.attribute_map.each_pair do |attr, param|
          value = self.send(attr)
          next if value.nil?
          hash[param] = _to_hash(value)
        end
        hash
      end

      # Outputs non-array value in the form of hash
      # For object, use to_hash. Otherwise, just return the value
      # @param [Object] value Any valid value
      # @return [Hash] Returns the value in the form of hash
      def _to_hash(value)
        if value.is_a?(Array)
          value.compact.map { |v| _to_hash(v) }
        elsif value.is_a?(Hash)
          {}.tap do |hash|
            value.each { |k, v| hash[k] = _to_hash(v) }
          end
        elsif value.respond_to? :to_hash
          value.to_hash
        else
          value
        end
      end
    end
  end
end
