=begin
#Zoom API

#The Zoom API allows developers to safely and securely access information from Zoom. You can use this API to build private services or public applications on the [Zoom App Marketplace](http://marketplace.zoom.us). To learn how to get your credentials and create private/public applications, read our [Authorization Guide](https://marketplace.zoom.us/docs/guides/authorization/credentials). All endpoints are available via `https` and are located at `api.zoom.us/v2/`.  For instance you can list all users on an account via `https://api.zoom.us/v2/users/`.

OpenAPI spec version: 2.0.0
Contact: developersupport@zoom.us
Generated by: https://github.com/swagger-api/swagger-codegen.git
Swagger Codegen version: 2.4.12

=end

require 'date'

module ZoomUs
  module Models
    # The user object represents a specific user on Zoom.
    class User
      # User's first name.
      attr_accessor :first_name

      # User's last name.
      attr_accessor :last_name

      # User's email address.
      attr_accessor :email

      # User's plan type:<br>`1` - Basic.<br>`2` - Licensed.<br>`3` - On-prem.
      attr_accessor :type

      # User's [role](https://support.zoom.us/hc/en-us/articles/115001078646-Role-Based-Access-Control) name.
      attr_accessor :role_name

      # Personal meeting ID.
      attr_accessor :pmi

      # Use Personal Meeting ID for instant meetings.
      attr_accessor :use_pmi

      # The time zone of the user.
      attr_accessor :timezone

      # Department.
      attr_accessor :dept

      # User create time.
      attr_accessor :created_at

      # User last login time.
      attr_accessor :last_login_time

      # User last login client version.
      attr_accessor :last_client_version

      # Attribute mapping from ruby-style variable name to JSON key.
      def self.attribute_map
        {
          :'first_name' => :'first_name',
          :'last_name' => :'last_name',
          :'email' => :'email',
          :'type' => :'type',
          :'role_name' => :'role_name',
          :'pmi' => :'pmi',
          :'use_pmi' => :'use_pmi',
          :'timezone' => :'timezone',
          :'dept' => :'dept',
          :'created_at' => :'created_at',
          :'last_login_time' => :'last_login_time',
          :'last_client_version' => :'last_client_version'
        }
      end

      # Attribute type mapping.
      def self.swagger_types
        {
          :'first_name' => :'String',
          :'last_name' => :'String',
          :'email' => :'String',
          :'type' => :'Integer',
          :'role_name' => :'String',
          :'pmi' => :'Integer',
          :'use_pmi' => :'BOOLEAN',
          :'timezone' => :'String',
          :'dept' => :'String',
          :'created_at' => :'DateTime',
          :'last_login_time' => :'DateTime',
          :'last_client_version' => :'String'
        }
      end

      # Initializes the object
      # @param [Hash] attributes Model attributes in the form of hash
      def initialize(attributes = {})
        return unless attributes.is_a?(Hash)

        # convert string to symbol for hash key
        attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

        if attributes.has_key?(:'first_name')
          self.first_name = attributes[:'first_name']
        end

        if attributes.has_key?(:'last_name')
          self.last_name = attributes[:'last_name']
        end

        if attributes.has_key?(:'email')
          self.email = attributes[:'email']
        else
          self.email = 'john.doe@email.com'
        end

        if attributes.has_key?(:'type')
          self.type = attributes[:'type']
        end

        if attributes.has_key?(:'role_name')
          self.role_name = attributes[:'role_name']
        end

        if attributes.has_key?(:'pmi')
          self.pmi = attributes[:'pmi']
        end

        if attributes.has_key?(:'use_pmi')
          self.use_pmi = attributes[:'use_pmi']
        else
          self.use_pmi = false
        end

        if attributes.has_key?(:'timezone')
          self.timezone = attributes[:'timezone']
        end

        if attributes.has_key?(:'dept')
          self.dept = attributes[:'dept']
        end

        if attributes.has_key?(:'created_at')
          self.created_at = attributes[:'created_at']
        end

        if attributes.has_key?(:'last_login_time')
          self.last_login_time = attributes[:'last_login_time']
        end

        if attributes.has_key?(:'last_client_version')
          self.last_client_version = attributes[:'last_client_version']
        end
      end

      # Show invalid properties with the reasons. Usually used together with valid?
      # @return Array for valid properties with the reasons
      def list_invalid_properties
        invalid_properties = Array.new
        if !@first_name.nil? && @first_name.to_s.length > 64
          invalid_properties.push('invalid value for "first_name", the character length must be smaller than or equal to 64.')
        end

        if !@last_name.nil? && @last_name.to_s.length > 64
          invalid_properties.push('invalid value for "last_name", the character length must be smaller than or equal to 64.')
        end

        if @email.nil?
          invalid_properties.push('invalid value for "email", email cannot be nil.')
        end

        if @type.nil?
          invalid_properties.push('invalid value for "type", type cannot be nil.')
        end

        invalid_properties
      end

      # Check to see if the all the properties in the model are valid
      # @return true if the model is valid
      def valid?
        return false if !@first_name.nil? && @first_name.to_s.length > 64
        return false if !@last_name.nil? && @last_name.to_s.length > 64
        return false if @email.nil?
        return false if @type.nil?
        true
      end

      # Custom attribute writer method with validation
      # @param [Object] first_name Value to be assigned
      def first_name=(first_name)
        if !first_name.nil? && first_name.to_s.length > 64
          fail ArgumentError, 'invalid value for "first_name", the character length must be smaller than or equal to 64.'
        end

        @first_name = first_name
      end

      # Custom attribute writer method with validation
      # @param [Object] last_name Value to be assigned
      def last_name=(last_name)
        if !last_name.nil? && last_name.to_s.length > 64
          fail ArgumentError, 'invalid value for "last_name", the character length must be smaller than or equal to 64.'
        end

        @last_name = last_name
      end

      # Checks equality by comparing each attribute.
      # @param [Object] Object to be compared
      def ==(o)
        return true if self.equal?(o)
        self.class == o.class &&
          first_name == o.first_name &&
          last_name == o.last_name &&
          email == o.email &&
          type == o.type &&
          role_name == o.role_name &&
          pmi == o.pmi &&
          use_pmi == o.use_pmi &&
          timezone == o.timezone &&
          dept == o.dept &&
          created_at == o.created_at &&
          last_login_time == o.last_login_time &&
          last_client_version == o.last_client_version
      end

      # @see the `==` method
      # @param [Object] Object to be compared
      def eql?(o)
        self == o
      end

      # Calculates hash code according to all attributes.
      # @return [Fixnum] Hash code
      def hash
        [first_name, last_name, email, type, role_name, pmi, use_pmi, timezone, dept, created_at, last_login_time, last_client_version].hash
      end

      # Builds the object from hash
      # @param [Hash] attributes Model attributes in the form of hash
      # @return [Object] Returns the model itself
      def build_from_hash(attributes)
        return nil unless attributes.is_a?(Hash)
        self.class.swagger_types.each_pair do |key, type|
          if type =~ /\AArray<(.*)>/i
            # check to ensure the input is an array given that the the attribute
            # is documented as an array but the input is not
            if attributes[self.class.attribute_map[key]].is_a?(Array)
              self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
            end
          elsif !attributes[self.class.attribute_map[key]].nil?
            self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
          end # or else data not found in attributes(hash), not an issue as the data can be optional
        end

        self
      end

      # Deserializes the data based on type
      # @param string type Data type
      # @param string value Value to be deserialized
      # @return [Object] Deserialized data
      def _deserialize(type, value)
        case type.to_sym
        when :DateTime
          ::DateTime.parse(value)
        when :Date
          ::Date.parse(value)
        when :String
          value.to_s
        when :Integer
          value.to_i
        when :Float
          value.to_f
        when :BOOLEAN
          if value.to_s =~ /\A(true|t|yes|y|1)\z/i
            true
          else
            false
          end
        when :Object
          # generic object (usually a Hash), return directly
          value
        when /\AArray<(?<inner_type>.+)>\z/
          inner_type = Regexp.last_match[:inner_type]
          value.map { |v| _deserialize(inner_type, v) }
        when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
          k_type = Regexp.last_match[:k_type]
          v_type = Regexp.last_match[:v_type]
          {}.tap do |hash|
            value.each do |k, v|
              hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
            end
          end
        else # model
          temp_model = Models.const_get(type).new
          temp_model.build_from_hash(value)
        end
      end

      # Returns the string representation of the object
      # @return [String] String presentation of the object
      def to_s
        to_hash.to_s
      end

      # to_body is an alias to to_hash (backward compatibility)
      # @return [Hash] Returns the object in the form of hash
      def to_body
        to_hash
      end

      # Returns the object in the form of hash
      # @return [Hash] Returns the object in the form of hash
      def to_hash
        hash = {}
        self.class.attribute_map.each_pair do |attr, param|
          value = self.send(attr)
          next if value.nil?
          hash[param] = _to_hash(value)
        end
        hash
      end

      # Outputs non-array value in the form of hash
      # For object, use to_hash. Otherwise, just return the value
      # @param [Object] value Any valid value
      # @return [Hash] Returns the value in the form of hash
      def _to_hash(value)
        if value.is_a?(Array)
          value.compact.map { |v| _to_hash(v) }
        elsif value.is_a?(Hash)
          {}.tap do |hash|
            value.each { |k, v| hash[k] = _to_hash(v) }
          end
        elsif value.respond_to? :to_hash
          value.to_hash
        else
          value
        end
      end
    end
  end
end
