=begin
#Zoom API

#The Zoom API allows developers to safely and securely access information from Zoom. You can use this API to build private services or public applications on the [Zoom App Marketplace](http://marketplace.zoom.us). To learn how to get your credentials and create private/public applications, read our [Authorization Guide](https://marketplace.zoom.us/docs/guides/authorization/credentials). All endpoints are available via `https` and are located at `api.zoom.us/v2/`.  For instance you can list all users on an account via `https://api.zoom.us/v2/users/`.

OpenAPI spec version: 2.0.0
Contact: developersupport@zoom.us
Generated by: https://github.com/swagger-api/swagger-codegen.git
Swagger Codegen version: 2.4.12

=end

require 'date'

module ZoomUs
  module Models
    # Webinar settings.
    class WebinarSettings
      # Start video when host joins webinar.
      attr_accessor :host_video

      # Start video when panelists join webinar.
      attr_accessor :panelists_video

      # Enable practice session.
      attr_accessor :practice_session

      # Default to HD video.
      attr_accessor :hd_video

      # `0` - Automatically approve.<br>`1` - Manually approve.<br>`2` - No registration required.
      attr_accessor :approval_type

      # Registration types. Only used for recurring webinars with a fixed time.<br>`1` - Attendees register once and can attend any of the webinar sessions.<br>`2` - Attendees need to register for each session in order to attend.<br>`3` - Attendees register once and can choose one or more sessions to attend.
      attr_accessor :registration_type

      # Determine how participants can join the audio portion of the webinar.
      attr_accessor :audio

      # Automatic recording:<br>`local` - Record on local.<br>`cloud` -  Record on cloud.<br>`none` - Disabled.
      attr_accessor :auto_recording

      # Only signed-in users can join this webinar.
      attr_accessor :enforce_login

      # Only signed-in users with specified domains can join webinars.
      attr_accessor :enforce_login_domains

      # Alternative host emails or IDs. Multiple values separated by comma.
      attr_accessor :alternative_hosts

      # Close registration after event date.
      attr_accessor :close_registration

      # Show social share buttons on the registration page.
      attr_accessor :show_share_button

      # Allow attendees to join from multiple devices.
      attr_accessor :allow_multiple_devices

      # Make the webinar on-demand
      attr_accessor :on_demand

      # List of global dial-in countries
      attr_accessor :global_dial_in_countries

      # Contact name for registration
      attr_accessor :contact_name

      # Contact email for registration
      attr_accessor :contact_email

      # Send confirmation email to registrants
      attr_accessor :registrants_confirmation_email

      # Restrict number of registrants for a webinar. By default, it is set to `0`. A `0` value means that the restriction option is disabled. Provide a number higher than 0 to restrict the webinar registrants by the that number.
      attr_accessor :registrants_restrict_number

      # Send notification email to registrants when the host updates a webinar.
      attr_accessor :notify_registrants

      # Zoom will open a survey page in attendees' browsers after leaving the webinar
      attr_accessor :post_webinar_survey

      # Survey url for post webinar survey
      attr_accessor :survey_url

      # registrants email notification
      attr_accessor :registrants_email_notification

      # Only authenticated users can join meetings
      attr_accessor :meeting_authentication

      # Meeting authentication option id
      attr_accessor :authentication_option

      # Meeting authentication domains
      attr_accessor :authentication_domains

      class EnumAttributeValidator
        attr_reader :datatype
        attr_reader :allowable_values

        def initialize(datatype, allowable_values)
          @allowable_values = allowable_values.map do |value|
            case datatype.to_s
            when /Integer/i
              value.to_i
            when /Float/i
              value.to_f
            else
              value
            end
          end
        end

        def valid?(value)
          !value || allowable_values.include?(value)
        end
      end

      # Attribute mapping from ruby-style variable name to JSON key.
      def self.attribute_map
        {
          :'host_video' => :'host_video',
          :'panelists_video' => :'panelists_video',
          :'practice_session' => :'practice_session',
          :'hd_video' => :'hd_video',
          :'approval_type' => :'approval_type',
          :'registration_type' => :'registration_type',
          :'audio' => :'audio',
          :'auto_recording' => :'auto_recording',
          :'enforce_login' => :'enforce_login',
          :'enforce_login_domains' => :'enforce_login_domains',
          :'alternative_hosts' => :'alternative_hosts',
          :'close_registration' => :'close_registration',
          :'show_share_button' => :'show_share_button',
          :'allow_multiple_devices' => :'allow_multiple_devices',
          :'on_demand' => :'on_demand',
          :'global_dial_in_countries' => :'global_dial_in_countries',
          :'contact_name' => :'contact_name',
          :'contact_email' => :'contact_email',
          :'registrants_confirmation_email' => :'registrants_confirmation_email',
          :'registrants_restrict_number' => :'registrants_restrict_number',
          :'notify_registrants' => :'notify_registrants',
          :'post_webinar_survey' => :'post_webinar_survey',
          :'survey_url' => :'survey_url',
          :'registrants_email_notification' => :'registrants_email_notification',
          :'meeting_authentication' => :'meeting_authentication',
          :'authentication_option' => :'authentication_option',
          :'authentication_domains' => :'authentication_domains'
        }
      end

      # Attribute type mapping.
      def self.swagger_types
        {
          :'host_video' => :'BOOLEAN',
          :'panelists_video' => :'BOOLEAN',
          :'practice_session' => :'BOOLEAN',
          :'hd_video' => :'BOOLEAN',
          :'approval_type' => :'Integer',
          :'registration_type' => :'Integer',
          :'audio' => :'String',
          :'auto_recording' => :'String',
          :'enforce_login' => :'BOOLEAN',
          :'enforce_login_domains' => :'String',
          :'alternative_hosts' => :'String',
          :'close_registration' => :'BOOLEAN',
          :'show_share_button' => :'BOOLEAN',
          :'allow_multiple_devices' => :'BOOLEAN',
          :'on_demand' => :'BOOLEAN',
          :'global_dial_in_countries' => :'Array<String>',
          :'contact_name' => :'String',
          :'contact_email' => :'String',
          :'registrants_confirmation_email' => :'BOOLEAN',
          :'registrants_restrict_number' => :'Integer',
          :'notify_registrants' => :'BOOLEAN',
          :'post_webinar_survey' => :'BOOLEAN',
          :'survey_url' => :'String',
          :'registrants_email_notification' => :'BOOLEAN',
          :'meeting_authentication' => :'BOOLEAN',
          :'authentication_option' => :'String',
          :'authentication_domains' => :'String'
        }
      end

      # Initializes the object
      # @param [Hash] attributes Model attributes in the form of hash
      def initialize(attributes = {})
        return unless attributes.is_a?(Hash)

        # convert string to symbol for hash key
        attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

        if attributes.has_key?(:'host_video')
          self.host_video = attributes[:'host_video']
        end

        if attributes.has_key?(:'panelists_video')
          self.panelists_video = attributes[:'panelists_video']
        end

        if attributes.has_key?(:'practice_session')
          self.practice_session = attributes[:'practice_session']
        else
          self.practice_session = false
        end

        if attributes.has_key?(:'hd_video')
          self.hd_video = attributes[:'hd_video']
        else
          self.hd_video = false
        end

        if attributes.has_key?(:'approval_type')
          self.approval_type = attributes[:'approval_type']
        end

        if attributes.has_key?(:'registration_type')
          self.registration_type = attributes[:'registration_type']
        end

        if attributes.has_key?(:'audio')
          self.audio = attributes[:'audio']
        else
          self.audio = 'both'
        end

        if attributes.has_key?(:'auto_recording')
          self.auto_recording = attributes[:'auto_recording']
        else
          self.auto_recording = 'none'
        end

        if attributes.has_key?(:'enforce_login')
          self.enforce_login = attributes[:'enforce_login']
        end

        if attributes.has_key?(:'enforce_login_domains')
          self.enforce_login_domains = attributes[:'enforce_login_domains']
        end

        if attributes.has_key?(:'alternative_hosts')
          self.alternative_hosts = attributes[:'alternative_hosts']
        end

        if attributes.has_key?(:'close_registration')
          self.close_registration = attributes[:'close_registration']
        end

        if attributes.has_key?(:'show_share_button')
          self.show_share_button = attributes[:'show_share_button']
        end

        if attributes.has_key?(:'allow_multiple_devices')
          self.allow_multiple_devices = attributes[:'allow_multiple_devices']
        end

        if attributes.has_key?(:'on_demand')
          self.on_demand = attributes[:'on_demand']
        else
          self.on_demand = false
        end

        if attributes.has_key?(:'global_dial_in_countries')
          if (value = attributes[:'global_dial_in_countries']).is_a?(Array)
            self.global_dial_in_countries = value
          end
        end

        if attributes.has_key?(:'contact_name')
          self.contact_name = attributes[:'contact_name']
        end

        if attributes.has_key?(:'contact_email')
          self.contact_email = attributes[:'contact_email']
        end

        if attributes.has_key?(:'registrants_confirmation_email')
          self.registrants_confirmation_email = attributes[:'registrants_confirmation_email']
        end

        if attributes.has_key?(:'registrants_restrict_number')
          self.registrants_restrict_number = attributes[:'registrants_restrict_number']
        end

        if attributes.has_key?(:'notify_registrants')
          self.notify_registrants = attributes[:'notify_registrants']
        end

        if attributes.has_key?(:'post_webinar_survey')
          self.post_webinar_survey = attributes[:'post_webinar_survey']
        end

        if attributes.has_key?(:'survey_url')
          self.survey_url = attributes[:'survey_url']
        end

        if attributes.has_key?(:'registrants_email_notification')
          self.registrants_email_notification = attributes[:'registrants_email_notification']
        end

        if attributes.has_key?(:'meeting_authentication')
          self.meeting_authentication = attributes[:'meeting_authentication']
        end

        if attributes.has_key?(:'authentication_option')
          self.authentication_option = attributes[:'authentication_option']
        end

        if attributes.has_key?(:'authentication_domains')
          self.authentication_domains = attributes[:'authentication_domains']
        end
      end

      # Show invalid properties with the reasons. Usually used together with valid?
      # @return Array for valid properties with the reasons
      def list_invalid_properties
        invalid_properties = Array.new
        if !@registrants_restrict_number.nil? && @registrants_restrict_number > 20000
          invalid_properties.push('invalid value for "registrants_restrict_number", must be smaller than or equal to 20000.')
        end

        if !@registrants_restrict_number.nil? && @registrants_restrict_number < 0
          invalid_properties.push('invalid value for "registrants_restrict_number", must be greater than or equal to 0.')
        end

        invalid_properties
      end

      # Check to see if the all the properties in the model are valid
      # @return true if the model is valid
      def valid?
        audio_validator = EnumAttributeValidator.new('String', ['both', 'telephony', 'voip'])
        return false unless audio_validator.valid?(@audio)
        auto_recording_validator = EnumAttributeValidator.new('String', ['local', 'cloud', 'none'])
        return false unless auto_recording_validator.valid?(@auto_recording)
        return false if !@registrants_restrict_number.nil? && @registrants_restrict_number > 20000
        return false if !@registrants_restrict_number.nil? && @registrants_restrict_number < 0
        true
      end

      # Custom attribute writer method checking allowed values (enum).
      # @param [Object] audio Object to be assigned
      def audio=(audio)
        validator = EnumAttributeValidator.new('String', ['both', 'telephony', 'voip'])
        unless validator.valid?(audio)
          fail ArgumentError, 'invalid value for "audio", must be one of #{validator.allowable_values}.'
        end
        @audio = audio
      end

      # Custom attribute writer method checking allowed values (enum).
      # @param [Object] auto_recording Object to be assigned
      def auto_recording=(auto_recording)
        validator = EnumAttributeValidator.new('String', ['local', 'cloud', 'none'])
        unless validator.valid?(auto_recording)
          fail ArgumentError, 'invalid value for "auto_recording", must be one of #{validator.allowable_values}.'
        end
        @auto_recording = auto_recording
      end

      # Custom attribute writer method with validation
      # @param [Object] registrants_restrict_number Value to be assigned
      def registrants_restrict_number=(registrants_restrict_number)
        if !registrants_restrict_number.nil? && registrants_restrict_number > 20000
          fail ArgumentError, 'invalid value for "registrants_restrict_number", must be smaller than or equal to 20000.'
        end

        if !registrants_restrict_number.nil? && registrants_restrict_number < 0
          fail ArgumentError, 'invalid value for "registrants_restrict_number", must be greater than or equal to 0.'
        end

        @registrants_restrict_number = registrants_restrict_number
      end

      # Checks equality by comparing each attribute.
      # @param [Object] Object to be compared
      def ==(o)
        return true if self.equal?(o)
        self.class == o.class &&
          host_video == o.host_video &&
          panelists_video == o.panelists_video &&
          practice_session == o.practice_session &&
          hd_video == o.hd_video &&
          approval_type == o.approval_type &&
          registration_type == o.registration_type &&
          audio == o.audio &&
          auto_recording == o.auto_recording &&
          enforce_login == o.enforce_login &&
          enforce_login_domains == o.enforce_login_domains &&
          alternative_hosts == o.alternative_hosts &&
          close_registration == o.close_registration &&
          show_share_button == o.show_share_button &&
          allow_multiple_devices == o.allow_multiple_devices &&
          on_demand == o.on_demand &&
          global_dial_in_countries == o.global_dial_in_countries &&
          contact_name == o.contact_name &&
          contact_email == o.contact_email &&
          registrants_confirmation_email == o.registrants_confirmation_email &&
          registrants_restrict_number == o.registrants_restrict_number &&
          notify_registrants == o.notify_registrants &&
          post_webinar_survey == o.post_webinar_survey &&
          survey_url == o.survey_url &&
          registrants_email_notification == o.registrants_email_notification &&
          meeting_authentication == o.meeting_authentication &&
          authentication_option == o.authentication_option &&
          authentication_domains == o.authentication_domains
      end

      # @see the `==` method
      # @param [Object] Object to be compared
      def eql?(o)
        self == o
      end

      # Calculates hash code according to all attributes.
      # @return [Fixnum] Hash code
      def hash
        [host_video, panelists_video, practice_session, hd_video, approval_type, registration_type, audio, auto_recording, enforce_login, enforce_login_domains, alternative_hosts, close_registration, show_share_button, allow_multiple_devices, on_demand, global_dial_in_countries, contact_name, contact_email, registrants_confirmation_email, registrants_restrict_number, notify_registrants, post_webinar_survey, survey_url, registrants_email_notification, meeting_authentication, authentication_option, authentication_domains].hash
      end

      # Builds the object from hash
      # @param [Hash] attributes Model attributes in the form of hash
      # @return [Object] Returns the model itself
      def build_from_hash(attributes)
        return nil unless attributes.is_a?(Hash)
        self.class.swagger_types.each_pair do |key, type|
          if type =~ /\AArray<(.*)>/i
            # check to ensure the input is an array given that the the attribute
            # is documented as an array but the input is not
            if attributes[self.class.attribute_map[key]].is_a?(Array)
              self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
            end
          elsif !attributes[self.class.attribute_map[key]].nil?
            self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
          end # or else data not found in attributes(hash), not an issue as the data can be optional
        end

        self
      end

      # Deserializes the data based on type
      # @param string type Data type
      # @param string value Value to be deserialized
      # @return [Object] Deserialized data
      def _deserialize(type, value)
        case type.to_sym
        when :DateTime
          ::DateTime.parse(value)
        when :Date
          ::Date.parse(value)
        when :String
          value.to_s
        when :Integer
          value.to_i
        when :Float
          value.to_f
        when :BOOLEAN
          if value.to_s =~ /\A(true|t|yes|y|1)\z/i
            true
          else
            false
          end
        when :Object
          # generic object (usually a Hash), return directly
          value
        when /\AArray<(?<inner_type>.+)>\z/
          inner_type = Regexp.last_match[:inner_type]
          value.map { |v| _deserialize(inner_type, v) }
        when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
          k_type = Regexp.last_match[:k_type]
          v_type = Regexp.last_match[:v_type]
          {}.tap do |hash|
            value.each do |k, v|
              hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
            end
          end
        else # model
          temp_model = Models.const_get(type).new
          temp_model.build_from_hash(value)
        end
      end

      # Returns the string representation of the object
      # @return [String] String presentation of the object
      def to_s
        to_hash.to_s
      end

      # to_body is an alias to to_hash (backward compatibility)
      # @return [Hash] Returns the object in the form of hash
      def to_body
        to_hash
      end

      # Returns the object in the form of hash
      # @return [Hash] Returns the object in the form of hash
      def to_hash
        hash = {}
        self.class.attribute_map.each_pair do |attr, param|
          value = self.send(attr)
          next if value.nil?
          hash[param] = _to_hash(value)
        end
        hash
      end

      # Outputs non-array value in the form of hash
      # For object, use to_hash. Otherwise, just return the value
      # @param [Object] value Any valid value
      # @return [Hash] Returns the value in the form of hash
      def _to_hash(value)
        if value.is_a?(Array)
          value.compact.map { |v| _to_hash(v) }
        elsif value.is_a?(Hash)
          {}.tap do |hash|
            value.each { |k, v| hash[k] = _to_hash(v) }
          end
        elsif value.respond_to? :to_hash
          value.to_hash
        else
          value
        end
      end
    end
  end
end
